==> javascript-frontend-2.21.0.4409-sources.jar: org/sonar/plugins/javascript/api/tree/declaration/SpecifierListTree.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2017 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.plugins.javascript.api.tree.declaration;

import com.google.common.annotations.Beta;
import org.sonar.javascript.tree.impl.SeparatedList;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;

/**
 * Interface for <a href="https://people.mozilla.org/~jorendorff/es6-draft.html#sec-exports">Export Clause</a>
 * (<a href="http://wiki.ecmascript.org/doku.php?id=harmony:specification_drafts">ES6</a>).
 * <pre>
 *    { {@link #specifiers()} }
 *    { {@link #specifiers()} , }
 * </pre>
 */
@Beta
public interface SpecifierListTree extends DeclarationTree {

  SyntaxToken openCurlyBraceToken();

  SeparatedList<SpecifierTree> specifiers();

  SyntaxToken closeCurlyBraceToken();

}

==> javascript-frontend-3.1.0.5111-sources.jar: org/sonar/plugins/javascript/api/tree/declaration/SpecifierListTree.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2017 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.plugins.javascript.api.tree.declaration;

import com.google.common.annotations.Beta;
import org.sonar.plugins.javascript.api.tree.SeparatedList;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;

/**
 * Interface for <a href="https://people.mozilla.org/~jorendorff/es6-draft.html#sec-exports">Export Clause</a>
 * (<a href="http://wiki.ecmascript.org/doku.php?id=harmony:specification_drafts">ES6</a>).
 * <pre>
 *    { {@link #specifiers()} }
 *    { {@link #specifiers()} , }
 * </pre>
 */
@Beta
public interface SpecifierListTree extends DeclarationTree {

  SyntaxToken openCurlyBraceToken();

  SeparatedList<SpecifierTree> specifiers();

  SyntaxToken closeCurlyBraceToken();

}
